@@ -1,8 +1,8 @@
 
-__version__ = "0.11.4"
+__version__ = "0.11.5"
 __version_vcs_info__ = {
-    'branch': 'master',
-    'revid': 'd65d838',
-    'revno': 1927}
+    'branch': 'hotfix-0.11.5',
+    'revid': '0d95224',
+    'revno': 1929}
 __version_user_email__ = "saxtouri@admin.grnet.gr"
 __version_user_name__ = "Stavros Sachtouris"
